[systemd-commits] src/libsystemd-bus

Kay Sievers kay at kemper.freedesktop.org
Thu May 2 10:21:09 PDT 2013


 src/libsystemd-bus/bus-kernel.c |   57 ++++++++++++++++++-----------------
 src/libsystemd-bus/kdbus.h      |   65 ++++++++++------------------------------
 2 files changed, 47 insertions(+), 75 deletions(-)

New commits:
commit febfd508297280846588f0e97514065ac23945bc
Author: Kay Sievers <kay at vrfy.org>
Date:   Thu May 2 19:01:49 2013 +0200

    kdbus: update kdbus.h from upstream

diff --git a/src/libsystemd-bus/bus-kernel.c b/src/libsystemd-bus/bus-kernel.c
index c35d957..0762b78 100644
--- a/src/libsystemd-bus/bus-kernel.c
+++ b/src/libsystemd-bus/bus-kernel.c
@@ -41,6 +41,9 @@
              (uint8_t *)(item) < (uint8_t *)(head) + (head)->size;              \
              item = KDBUS_ITEM_NEXT(item))
 
+#define KDBUS_ITEM_HEADER_SIZE offsetof(struct kdbus_item, data)
+#define KDBUS_ITEM_SIZE(s) ALIGN8((s) + KDBUS_ITEM_HEADER_SIZE)
+
 static int parse_unique_name(const char *s, uint64_t *id) {
         int r;
 
@@ -57,61 +60,61 @@ static int parse_unique_name(const char *s, uint64_t *id) {
         return 1;
 }
 
-static void append_payload_vec(struct kdbus_msg_item **d, const void *p, size_t sz) {
+static void append_payload_vec(struct kdbus_item **d, const void *p, size_t sz) {
         assert(d);
         assert(p);
         assert(sz > 0);
 
         *d = ALIGN8_PTR(*d);
 
-        (*d)->size = offsetof(struct kdbus_msg_item, vec) + sizeof(struct kdbus_vec);
+        (*d)->size = offsetof(struct kdbus_item, vec) + sizeof(struct kdbus_vec);
         (*d)->type = KDBUS_MSG_PAYLOAD_VEC;
         (*d)->vec.address = (intptr_t) p;
         (*d)->vec.size = sz;
 
-        *d = (struct kdbus_msg_item *) ((uint8_t*) *d + (*d)->size);
+        *d = (struct kdbus_item *) ((uint8_t*) *d + (*d)->size);
 }
 
-static void append_destination(struct kdbus_msg_item **d, const char *s, size_t length) {
+static void append_destination(struct kdbus_item **d, const char *s, size_t length) {
         assert(d);
         assert(s);
 
         *d = ALIGN8_PTR(*d);
 
-        (*d)->size = offsetof(struct kdbus_msg_item, str) + length + 1;
+        (*d)->size = offsetof(struct kdbus_item, str) + length + 1;
         (*d)->type = KDBUS_MSG_DST_NAME;
         memcpy((*d)->str, s, length + 1);
 
-        *d = (struct kdbus_msg_item *) ((uint8_t*) *d + (*d)->size);
+        *d = (struct kdbus_item *) ((uint8_t*) *d + (*d)->size);
 }
 
-static void* append_bloom(struct kdbus_msg_item **d, size_t length) {
+static void* append_bloom(struct kdbus_item **d, size_t length) {
         void *r;
 
         assert(d);
 
         *d = ALIGN8_PTR(*d);
 
-        (*d)->size = offsetof(struct kdbus_msg_item, data) + length;
+        (*d)->size = offsetof(struct kdbus_item, data) + length;
         (*d)->type = KDBUS_MSG_BLOOM;
         r = (*d)->data;
 
-        *d = (struct kdbus_msg_item *) ((uint8_t*) *d + (*d)->size);
+        *d = (struct kdbus_item *) ((uint8_t*) *d + (*d)->size);
 
         return r;
 }
 
-static void append_fds(struct kdbus_msg_item **d, const int fds[], unsigned n_fds) {
+static void append_fds(struct kdbus_item **d, const int fds[], unsigned n_fds) {
         assert(d);
         assert(fds);
         assert(n_fds > 0);
 
         *d = ALIGN8_PTR(*d);
-        (*d)->size = offsetof(struct kdbus_msg_item, fds) + sizeof(int) * n_fds;
+        (*d)->size = offsetof(struct kdbus_item, fds) + sizeof(int) * n_fds;
         (*d)->type = KDBUS_MSG_UNIX_FDS;
         memcpy((*d)->fds, fds, sizeof(int) * n_fds);
 
-        *d = (struct kdbus_msg_item *) ((uint8_t*) *d + (*d)->size);
+        *d = (struct kdbus_item *) ((uint8_t*) *d + (*d)->size);
 }
 
 static int bus_message_setup_bloom(sd_bus_message *m, void *bloom) {
@@ -178,7 +181,7 @@ static int bus_message_setup_bloom(sd_bus_message *m, void *bloom) {
 }
 
 static int bus_message_setup_kmsg(sd_bus *b, sd_bus_message *m) {
-        struct kdbus_msg_item *d;
+        struct kdbus_item *d;
         bool well_known;
         uint64_t unique;
         size_t sz, dl;
@@ -203,20 +206,20 @@ static int bus_message_setup_kmsg(sd_bus *b, sd_bus_message *m) {
         sz = offsetof(struct kdbus_msg, items);
 
         /* Add in fixed header, fields header and payload */
-        sz += 3 * ALIGN8(offsetof(struct kdbus_msg_item, vec) + sizeof(struct kdbus_vec));
+        sz += 3 * ALIGN8(offsetof(struct kdbus_item, vec) + sizeof(struct kdbus_vec));
 
         /* Add space for bloom filter */
-        sz += ALIGN8(offsetof(struct kdbus_msg_item, data) + BLOOM_SIZE);
+        sz += ALIGN8(offsetof(struct kdbus_item, data) + BLOOM_SIZE);
 
         /* Add in well-known destination header */
         if (well_known) {
                 dl = strlen(m->destination);
-                sz += ALIGN8(offsetof(struct kdbus_msg_item, str) + dl + 1);
+                sz += ALIGN8(offsetof(struct kdbus_item, str) + dl + 1);
         }
 
         /* Add space for unix fds */
         if (m->n_fds > 0)
-                sz += ALIGN8(offsetof(struct kdbus_msg_item, fds) + sizeof(int)*m->n_fds);
+                sz += ALIGN8(offsetof(struct kdbus_item, fds) + sizeof(int)*m->n_fds);
 
         m->kdbus = memalign(8, sz);
         if (!m->kdbus)
@@ -354,20 +357,20 @@ int bus_kernel_write_message(sd_bus *bus, sd_bus_message *m) {
 }
 
 static void close_kdbus_msg(struct kdbus_msg *k) {
-        struct kdbus_msg_item *d;
+        struct kdbus_item *d;
 
         KDBUS_ITEM_FOREACH(d, k) {
 
                 if (d->type != KDBUS_MSG_UNIX_FDS)
                         continue;
 
-                close_many(d->fds, (d->size - offsetof(struct kdbus_msg_item, fds)) / sizeof(int));
+                close_many(d->fds, (d->size - offsetof(struct kdbus_item, fds)) / sizeof(int));
         }
 }
 
 static int bus_kernel_make_message(sd_bus *bus, struct kdbus_msg *k, sd_bus_message **ret) {
         sd_bus_message *m = NULL;
-        struct kdbus_msg_item *d;
+        struct kdbus_item *d;
         unsigned n_payload = 0, n_fds = 0;
         _cleanup_free_ int *fds = NULL;
         struct bus_header *h = NULL;
@@ -385,7 +388,7 @@ static int bus_kernel_make_message(sd_bus *bus, struct kdbus_msg *k, sd_bus_mess
         KDBUS_ITEM_FOREACH(d, k) {
                 size_t l;
 
-                l = d->size - offsetof(struct kdbus_msg_item, data);
+                l = d->size - offsetof(struct kdbus_item, data);
 
                 if (d->type == KDBUS_MSG_PAYLOAD) {
 
@@ -435,7 +438,7 @@ static int bus_kernel_make_message(sd_bus *bus, struct kdbus_msg *k, sd_bus_mess
         KDBUS_ITEM_FOREACH(d, k) {
                 size_t l;
 
-                l = d->size - offsetof(struct kdbus_msg_item, data);
+                l = d->size - offsetof(struct kdbus_item, data);
 
                 if (d->type == KDBUS_MSG_PAYLOAD) {
 
@@ -565,7 +568,7 @@ int bus_kernel_read_message(sd_bus *bus, sd_bus_message **m) {
 
 int bus_kernel_create(const char *name, char **s) {
         struct kdbus_cmd_bus_make *make;
-        struct kdbus_cmd_make_item *n, *cg;
+        struct kdbus_item *n, *cg;
         size_t l;
         int fd;
         char *p;
@@ -579,18 +582,18 @@ int bus_kernel_create(const char *name, char **s) {
 
         l = strlen(name);
         make = alloca0(offsetof(struct kdbus_cmd_bus_make, items) +
-                       sizeof(struct kdbus_cmd_make_item) + sizeof(uint64_t) +
-                       sizeof(struct kdbus_cmd_make_item) + DECIMAL_STR_MAX(uid_t) + 1 + l + 1);
+                       KDBUS_ITEM_HEADER_SIZE + sizeof(uint64_t) +
+                       KDBUS_ITEM_HEADER_SIZE + DECIMAL_STR_MAX(uid_t) + 1 + l + 1);
 
         cg = make->items;
         cg->type = KDBUS_MAKE_CGROUP;
         cg->data64[0] = 1;
-        cg->size = sizeof(struct kdbus_cmd_make_item) + sizeof(uint64_t);
+        cg->size = KDBUS_ITEM_HEADER_SIZE + sizeof(uint64_t);
 
         n = KDBUS_ITEM_NEXT(cg);
         n->type = KDBUS_MAKE_NAME;
         sprintf(n->str, "%lu-%s", (unsigned long) getuid(), name);
-        n->size = sizeof(struct kdbus_cmd_make_item) + strlen(n->str) + 1;
+        n->size = KDBUS_ITEM_HEADER_SIZE + strlen(n->str) + 1;
 
         make->size = offsetof(struct kdbus_cmd_bus_make, items) + cg->size + n->size;
         make->flags = KDBUS_MAKE_ACCESS_WORLD | KDBUS_MAKE_POLICY_OPEN;
diff --git a/src/libsystemd-bus/kdbus.h b/src/libsystemd-bus/kdbus.h
index 6d817b8..049c988 100644
--- a/src/libsystemd-bus/kdbus.h
+++ b/src/libsystemd-bus/kdbus.h
@@ -110,12 +110,12 @@ struct kdbus_vec {
 };
 
 /**
  * struct  kdbus_msg_item - chain of data blocks
  *
  * size: overall data record size
  * type: kdbus_msg_item type of data
  */
-struct kdbus_msg_item {
+struct kdbus_item {
 	__u64 size;
 	__u64 type;
 	union {
@@ -125,14 +125,19 @@ struct kdbus_msg_item {
 		__u64 data64[0];
 		char str[0];
 
+		/* connection */
+		__u64 id;
+
 		/* data vector */
 		struct kdbus_vec vec;
 
-		/* specific fields */
-		int fds[0];				/* int array of file descriptors */
+		/* process credentials and properties*/
 		struct kdbus_creds creds;
 		struct kdbus_audit audit;
 		struct kdbus_timestamp timestamp;
+
+		/* specific fields */
+		int fds[0];
 		struct kdbus_manager_msg_name_change name_change;
 		struct kdbus_manager_msg_id_change id_change;
 	};
@@ -171,7 +176,7 @@ struct kdbus_msg {
 		__u64 cookie_reply;	/* cookie we reply to */
 		__u64 timeout_ns;	/* timespan to wait for reply */
 	};
-	struct kdbus_msg_item items[0];
+	struct kdbus_item items[0];
 };
 
 enum {
@@ -233,16 +238,6 @@ enum {
 	KDBUS_HELLO_NULL,
 };
 
-struct kdbus_cmd_hello_item {
-	__u64 size;
-	__u64 type;
-	union {
-		__u8 data[0];
-		__u64 data64[0];
-		char str[0];
-	};
-};
-
 struct kdbus_cmd_hello {
 	__u64 size;
 
@@ -263,7 +258,7 @@ struct kdbus_cmd_hello {
 	__u64 id;		/* id assigned to this connection */
 	__u64 bloom_size;	/* The bloom filter size chosen by the
 				 * bus owner */
-	struct kdbus_cmd_hello_item items[0];
+	struct kdbus_item items[0];
 };
 
 /* Flags for kdbus_cmd_{bus,ep,ns}_make */
@@ -286,16 +281,6 @@ enum {
 				 * privileges */
 };
 
-struct kdbus_cmd_make_item {
-	__u64 size;
-	__u64 type;
-	union {
-		__u8 data[0];
-		__u64 data64[0];
-		char str[0];
-	};
-};
-
 struct kdbus_cmd_bus_make {
 	__u64 size;
 	__u64 flags;		/* userspace → kernel, kernel → userspace
@@ -307,7 +292,7 @@ struct kdbus_cmd_bus_make {
 				 * structure and returned from
 				 * KDBUS_CMD_HELLO, later */
 	__u64 bloom_size;	/* size of the bloom filter for this bus */
-	struct kdbus_cmd_make_item items[0];
+	struct kdbus_item items[0];
 
 };
 
@@ -319,7 +304,7 @@ struct kdbus_cmd_ep_make {
 				 * same way as for
 				 * KDBUS_CMD_BUS_MAKE. Unused for
 				 * now. */
-	struct kdbus_cmd_make_item items[0];
+	struct kdbus_item items[0];
 };
 
 struct kdbus_cmd_ns_make {
@@ -330,7 +315,7 @@ struct kdbus_cmd_ns_make {
 				 * same way as for
 				 * KDBUS_CMD_BUS_MAKE. Unused for
 				 * now. */
-	struct kdbus_cmd_make_item items[0];
+	struct kdbus_item items[0];
 };
 
 enum {
@@ -363,18 +348,12 @@ enum {
 	KDBUS_NAME_INFO_ITEM_AUDIT,	/* kernel → userspace */
 };
 
-struct kdbus_cmd_name_info_item {
-	__u64 size;
-	__u64 type;
-	__u8 data[0];
-};
-
 struct kdbus_cmd_name_info {
 	__u64 size;			/* overall size of info */
 	__u64 flags;
 	__u64 id;			/* either ID, or 0 and _ITEM_NAME follows */
 	struct kdbus_creds creds;
-	struct kdbus_cmd_name_info_item items[0]; /* list of item records */
+	struct kdbus_item items[0];	/* list of item records */
 };
 
 enum {
@@ -388,22 +367,12 @@ enum {
 	KDBUS_MATCH_ID_REMOVE,		/* Matches an ID against KDBUS_MSG_ID_REMOVE */
 };
 
-struct kdbus_cmd_match_item {
-	__u64 size;
-	__u64 type;
-	union {
-		__u64 id;
-		__u8 data[0];
-		char str[0];
-	};
-};
-
 struct kdbus_cmd_match {
 	__u64 size;
 	__u64 id;	/* We allow registration/deregestration of matches for other peers */
 	__u64 cookie;	/* userspace supplied cookie; when removing; kernel deletes everything with same cookie */
 	__u64 src_id;	/* ~0: any. other: exact unique match */
-	struct kdbus_cmd_match_item items[0];
+	struct kdbus_item items[0];
 };
 
 struct kdbus_cmd_monitor {
@@ -110,12 +110,12 @@ struct kdbus_vec {
 
 /**
- * struct  kdbus_msg_item - chain of data blocks
+ * struct  kdbus_item - chain of data blocks
  *
  * size: overall data record size
@@ -110,12 +110,12 @@ struct kdbus_vec {
  *
  * size: overall data record size
- * type: kdbus_msg_item type of data
+ * type: kdbus_item type of data
  */



More information about the systemd-commits mailing list